<?xml version="1.0" ?><!DOCTYPE TS><TS language="ru" version="2.0">
<context>
    <name>AddProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="27"/>
        <source>Please enter a profile name.</source>
        <translation>Введите название профиля.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="28"/>
        <source>A profile with this name already exists.</source>
        <translation>Профиль с таким названием уже существует.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="24"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="25"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>AddRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="80"/>
        <source>Repository Path:</source>
        <translation>Путь к репозиторию:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="83"/>
        <source>Choose Location of Borg Repository</source>
        <translation>Выберите расположение репозитория Borg</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="112"/>
        <source>Repository URL:</source>
        <translation>URL репозитория:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="138"/>
        <source>Unable to add your repository.</source>
        <translation>Не удалось добавить репозиторий.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="165"/>
        <source>Please enter a valid repo URL or select a local path.</source>
        <translation>Введите правильный URL репозитория или локальный путь.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="169"/>
        <source>This repo has already been added.</source>
        <translation>Этот репозиторий уже добавлен.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="105"/>
        <source>Show my passwords</source>
        <translation>Показать мои пароли</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="90"/>
        <source>Autofilled password from password manager.</source>
        <translation>Автоматически заполнять пароль из менеджера паролей</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="102"/>
        <source>Hide my passwords</source>
        <translation>Скрыть мои пароли</translation>
    </message>
</context>
<context>
    <name>AddRepository</name>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="60"/>
        <source>Initialize New Backup Repository</source>
        <translation>Создание нового репозитория</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="67"/>
        <source>Repository URL:</source>
        <translation>URL репозитория:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="82"/>
        <source>csvis8xq@csvis8xq.repo.borgbase.com:repo</source>
        <translation>csvis8xq@csvis8xq.repo.borgbase.com:repo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="89"/>
        <source>Choose a local path as repository.</source>
        <translation>Выбрать для репозитория локальный путь.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="103"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="201"/>
        <source>Encryption:</source>
        <translation>Шифрование:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="179"/>
        <source>SSH Key:</source>
        <translation>Ключ SSH:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="193"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Автоматически выбирать ключ SSH (по умолчанию)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="247"/>
        <source>Add</source>
        <translation>Добавить</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="254"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="33"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="158"/>
        <source>Advanced</source>
        <translation>Расширенные</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="218"/>
        <source>Extra Borg Arguments:</source>
        <translation>Дополнительные аргументы Borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="116"/>
        <source>Borg passphrase:</source>
        <translation>Пароль Borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="143"/>
        <source>Confirm passphrase:</source>
        <translation>Подтверждение пароля:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="150"/>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
</context>
<context>
    <name>ArchiveTab</name>
    <message>
        <location filename="../../views/archive_tab.py" line="144"/>
        <source>Archives for %s</source>
        <translation>Архивы в %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="177"/>
        <source>Archives</source>
        <translation>Архивы</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="194"/>
        <source>Preview: %s</source>
        <translation>Предпросмотр: %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="198"/>
        <source>Error in archive name template.</source>
        <translation>Ошибка в шаблоне названия архива.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="242"/>
        <source>Pruning finished.</source>
        <translation>Очистка завершена.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="261"/>
        <source>Refreshed archives.</source>
        <translation>Список архивов обновлён.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="315"/>
        <source>Choose Mount Point</source>
        <translation>Выберите точку монтирования</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="321"/>
        <source>Mounted successfully.</source>
        <translation>Монтирование успешно завершено.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="348"/>
        <source>Mount point not active.</source>
        <translation>Точка монтирования не активна.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="355"/>
        <source>Un-mounted successfully.</source>
        <translation>Размонтирование успешно завершено.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="393"/>
        <source>Select an archive to restore first.</source>
        <translation>Сначала выберите архив для восстановления.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="413"/>
        <source>Choose Extraction Point</source>
        <translation>Выберите точку извлечения</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="478"/>
        <source>Archive deleted.</source>
        <translation>Архив удален.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Confirm deletion</source>
        <translation>Подтверждение удаления</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="563"/>
        <source>No archive selected</source>
        <translation>Архив не выбран</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Are you sure you want to delete the archive?</source>
        <translation>Вы действительно хотите удалить архив?</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="449"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="450"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="98"/>
        <source>Action cancelled.</source>
        <translation>Действие отменено.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="361"/>
        <source>Unmounting failed. Make sure no programs are using {}</source>
        <translation>Сбой размонтирования. Убедитесь, что {} не используется другими программами</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="117"/>
        <source>Select an archive first.</source>
        <translation>Сначала выберите архив.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="537"/>
        <source>Change name</source>
        <translation>Переименование</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="537"/>
        <source>New archive name:</source>
        <translation>Новое название архива:</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="547"/>
        <source>Archive name cannot be blank.</source>
        <translation>Название архива не может быть пустым.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="552"/>
        <source>An archive with this name already exists.</source>
        <translation>Архив с таким названием уже существует.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="567"/>
        <source>Archive renamed.</source>
        <translation>Архив переименован.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="278"/>
        <source>Refreshed archive.</source>
        <translation>Архив обновлён.</translation>
    </message>
</context>
<context>
    <name>BorgBreakJob</name>
    <message>
        <location filename="../../borg/break_lock.py" line="8"/>
        <source>Breaking repository lock...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/break_lock.py" line="12"/>
        <source>Repository lock broken. Please redo your last action.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgCheckJob</name>
    <message>
        <location filename="../../borg/check.py" line="8"/>
        <source>Starting consistency check...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/check.py" line="17"/>
        <source>Check completed.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/check.py" line="14"/>
        <source>Repo check failed. See logs for details.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgCreateJob</name>
    <message>
        <location filename="../../borg/create.py" line="36"/>
        <source>Backup finished with warnings. See logs for details.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/create.py" line="38"/>
        <source>Backup finished.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/create.py" line="45"/>
        <source>Backup started.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgDeleteJob</name>
    <message>
        <location filename="../../borg/delete.py" line="8"/>
        <source>Deleting archive...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/delete.py" line="13"/>
        <source>Archive deleted.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgDiffJob</name>
    <message>
        <location filename="../../borg/diff.py" line="9"/>
        <source>Requesting differences between archives...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/diff.py" line="13"/>
        <source>Obtained differences between archives.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgExtractJob</name>
    <message>
        <location filename="../../borg/extract.py" line="8"/>
        <source>Downloading files from archive...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/extract.py" line="13"/>
        <source>Restored files from archive.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgInfoArchiveJob</name>
    <message>
        <location filename="../../borg/info_archive.py" line="9"/>
        <source>Refreshing archive...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/info_archive.py" line="14"/>
        <source>Refreshing archive done.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgInfoRepoJob</name>
    <message>
        <location filename="../../borg/info_repo.py" line="9"/>
        <source>Validating existing repo...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgInitJob</name>
    <message>
        <location filename="../../borg/init.py" line="8"/>
        <source>Setting up new repo...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgJob</name>
    <message>
        <location filename="../../borg/borg_job.py" line="66"/>
        <source>Files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="67"/>
        <source>Original</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="68"/>
        <source>Deduplicated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="69"/>
        <source>Compressed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="299"/>
        <source>Task started</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgListArchiveJob</name>
    <message>
        <location filename="../../borg/list_archive.py" line="8"/>
        <source>Getting archive content...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/list_archive.py" line="12"/>
        <source>Done getting archive content.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgListRepoJob</name>
    <message>
        <location filename="../../borg/list_repo.py" line="10"/>
        <source>Refreshing archives...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/list_repo.py" line="15"/>
        <source>Refreshing archives done.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgMountJob</name>
    <message>
        <location filename="../../borg/mount.py" line="9"/>
        <source>Mounting archive into folder...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgPruneJob</name>
    <message>
        <location filename="../../borg/prune.py" line="9"/>
        <source>Pruning old archives...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../borg/prune.py" line="14"/>
        <source>Pruning done.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BorgUmountJob</name>
    <message>
        <location filename="../../borg/umount.py" line="10"/>
        <source>Unmounting archive...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалог</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="25"/>
        <source>Archive:</source>
        <translation>Архив:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</source>
        <translation>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="63"/>
        <source>Note: If you select a top-level folder and deselect its children, they will still be restored.</source>
        <translation>Внимание: Если вы отметите папку, но не ее подпапки, они все равно будут восстановлены.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="88"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="95"/>
        <source>Extract</source>
        <translation>Извлечь</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="35"/>
        <source>Add Backup Profile</source>
        <translation>Добавление профиля</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Backup profiles allow for granular backups from different sources to different destinations. You could e.g. back up essential documents to a remote repository via Wifi, while doing a full backup onto a local storage device.&lt;/p&gt;&lt;p&gt;Repositories and SSH keys are shared between profiles. Source folders, active destination repo, allowed networks, pruning, validation and scheduling are per-profile.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Профили архивации позволяют архивировать файлы из различных источников в различные хранилища. Например, можно архивировать важные документы на удалённый репозиторий через Wifi, а полный архив хранить на локальном устройстве.&lt;/p&gt;&lt;p&gt;Репозитории и ключи SSH доступны всем профилям. Исходные папки, выбранный репозиторий, разрешённые сети, очистка, проверка и расписание задаются отдельно для каждого профиля.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="84"/>
        <source>Profile Name</source>
        <translation>Название профиля</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="43"/>
        <source>Generate SSH Key</source>
        <translation>Создать ключ SSH</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="55"/>
        <source>Key Format:</source>
        <translation>Формат ключа:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="72"/>
        <source>Key Length:</source>
        <translation>Длина ключа:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="94"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 or 4096 for RSA, 384 or 521 for ECDSA. Fixed for Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;More&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 или 4096 для RSA, 384 или 521 для ECDSA. Фиксировано для Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Еще&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="107"/>
        <source>Output File:</source>
        <translation>Выходной файл:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="119"/>
        <source>Don&apos;t change this if you want SSH to automatically find the key.</source>
        <translation>Не изменяйте, если вы хотите, чтобы SSH автоматически нашел ключ.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="128"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="141"/>
        <source>Generate and copy to Clipboard</source>
        <translation>Создать и скопировать в буфер обмена</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="25"/>
        <source>Select two archives</source>
        <translation>Выберите два архива</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="60"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="65"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="70"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="75"/>
        <source>Mount Point</source>
        <translation>Точка монтирования</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="80"/>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="113"/>
        <source>Diff</source>
        <translation>Сравнить</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="25"/>
        <source>Difference between</source>
        <translation>Разница между</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 </source>
        <translation>nyx2.local-2018-11-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="45"/>
        <source>and</source>
        <translation>и</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="58"/>
        <source>nyx2.local-2018-10-16T09:49:58 </source>
        <translation>nyx2.local-2018-10-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="101"/>
        <source>Ok</source>
        <translation>ОК</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="23"/>
        <source>If set, sharing this file with others will disclose your borg passphrase. Use with caution!</source>
        <translation>Если включено, то при передаче этого файла другим лицам ваш пароль Borg будет раскрыт. Используйте с осторожностью!</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="26"/>
        <source>Include borg passphrase in export</source>
        <translation>Включить пароль Borg в экспорт</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="25"/>
        <source>Borg passphrase:</source>
        <translation>Пароль Borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="53"/>
        <source>Overwrite existing profile</source>
        <translation>Перезаписать существующий профиль</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="60"/>
        <source>Overwrite existing settings</source>
        <translation>Перезаписать существующие настройки</translation>
    </message>
</context>
<context>
    <name>EditProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="68"/>
        <source>Rename Profile</source>
        <translation>Переименование профиля</translation>
    </message>
</context>
<context>
    <name>ExistingRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="192"/>
        <source>Connect to existing Repository</source>
        <translation>Подключение к существующему репозиторию</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="210"/>
        <source>Show my password</source>
        <translation>Показать мой пароль</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="207"/>
        <source>Hide my password</source>
        <translation>Скрыть мой пароль</translation>
    </message>
</context>
<context>
    <name>ExportWindow</name>
    <message>
        <location filename="../../views/export_window.py" line="29"/>
        <source>Export Profile</source>
        <translation>Экспорт профиля</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="38"/>
        <source>The current profile_export has no password</source>
        <translation>Текущий profile_export не имеет пароля</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="43"/>
        <source>Save profile_export</source>
        <translation>Сохранить profile_export</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="55"/>
        <source>Error while exporting</source>
        <translation>Ошибка при экспорте</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="71"/>
        <source>The file {} could not be created. Please choose another location.</source>
        <translation>Файл {} не может быть создан. Пожалуйста, выберите другое место.</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export successful!</source>
        <translation>Профиль успешно экспортирован!</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export written to {}.</source>
        <translation>Профиль экспортирован в {}.</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="14"/>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="44"/>
        <source>Archives</source>
        <translation>Архивы</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="72"/>
        <source>Date</source>
        <translation>Дата</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="79"/>
        <source>Size</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="82"/>
        <source>Duration</source>
        <translation>Длительность</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="87"/>
        <source>Mount Point</source>
        <translation>Точка монтирования</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="92"/>
        <source>Name</source>
        <translation>Название</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="125"/>
        <source>Check</source>
        <translation>Проверить</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="145"/>
        <source>Prune</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="155"/>
        <source>Refresh</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="202"/>
        <source>Prune Options and Archive Naming</source>
        <translation>Параметры очистки и названий архивов</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="229"/>
        <source>Keep</source>
        <translation>Хранить архивов </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="256"/>
        <source>Use -1 for unlimited.</source>
        <translation>-1 = неограниченно.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="249"/>
        <source> hourly, </source>
        <translation> за час, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="269"/>
        <source> daily, </source>
        <translation> за день, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="283"/>
        <source> weekly, </source>
        <translation> за неделю, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="297"/>
        <source> monthly and</source>
        <translation> за месяц и </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="311"/>
        <source> annual archives</source>
        <translation> за год</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="338"/>
        <source>No matter what, keep all archives of the last:</source>
        <translation>Всегда сохранять архивы за последние:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="348"/>
        <source>24H, 1d, 52w, 12m, 1y</source>
        <translation>24H, 1d, 52w, 12m, 1y</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="388"/>
        <source>Archive Name:</source>
        <translation>Название архива:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="431"/>
        <source>Available variables: hostname, profile_id, profile_slug, now, utc_now, user</source>
        <translation>Доступные переменные: hostname, profile_id, profile_slug, now, utc_now, user</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="398"/>
        <source>{hostname}-{profile_slug}-</source>
        <translation>{hostname}-{profile_slug}-</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="441"/>
        <source>Prune Prefix:</source>
        <translation>Префикс очистки:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="71"/>
        <source>0.0</source>
        <translation>0.0</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="55"/>
        <source>Repository:</source>
        <translation>Репозиторий:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="128"/>
        <source>Select Backup Destination</source>
        <translation>Выбор хранилища архивов</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="136"/>
        <source>Unlink Repository (This doesn&apos;t delete any data. You can always add a repo again later.)</source>
        <translation>Отвязать репозиторий (При этом данные не удаляются. Вы всегда можете переподключиться к нему позднее.)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="164"/>
        <source>SSH Key:</source>
        <translation>Ключ SSH:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="185"/>
        <source>Copy public SSH key to clipboard.</source>
        <translation>Скопировать публичный SSH ключ в буфер обмена</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="222"/>
        <source>To securely access remote repositories. Keep default to use all your existing keys. Or create new key.</source>
        <translation>Для безопасного доступа к удалённым репозиториям. Оставьте значение по умолчанию, чтобы использовать все ваши существующие ключи. Или создайте новый ключ.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="246"/>
        <source>Compression:</source>
        <translation>Сжатие:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="347"/>
        <source>Encryption:</source>
        <translation>Шифрование:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="387"/>
        <source>Original Size:</source>
        <translation>Исходный размер:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="401"/>
        <source>Deduplicated Size:</source>
        <translation>После дедупликации:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="408"/>
        <source>Compressed Size:</source>
        <translation>После сжатия:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="45"/>
        <source>Schedule</source>
        <translation>Расписание</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="86"/>
        <source>Backup manually</source>
        <translation>Архивация вручную</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="143"/>
        <source>Backup every </source>
        <translation>Архивация каждые </translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="110"/>
        <source>Backup daily at</source>
        <translation>Архивация ежедневно в</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="279"/>
        <source>Validate repository data every</source>
        <translation>Проверять данные репозитория каждые</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="299"/>
        <source>weeks</source>
        <translation>нед.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="225"/>
        <source>Prune old Archives after each backup</source>
        <translation>Удалять старые архивы после каждой архивации</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="191"/>
        <source>Next Backup:</source>
        <translation>Следующая архивация:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="345"/>
        <source>Networks</source>
        <translation>Сети</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="357"/>
        <source>Allowed Networks:</source>
        <translation>Разрешенные сети:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="406"/>
        <source>Log</source>
        <translation>Журнал</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="431"/>
        <source>Time</source>
        <translation>Время</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="436"/>
        <source>Category</source>
        <translation>Категория</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="441"/>
        <source>Subcommand</source>
        <translation>Подкоманда</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="446"/>
        <source>Repository</source>
        <translation>Репозиторий</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="451"/>
        <source>Returncode</source>
        <translation>Код возврата</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="468"/>
        <source>Shell Commands</source>
        <translation>Команды оболочки</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="477"/>
        <source>Run custom shell commands before and after each backup. The actual backup and post-backup command will only run, if the pre-backup command exits without error (return code 0).</source>
        <translation>Запуск пользовательских команд оболочки до и после каждой архивации. Архивация и команда после архивации будут выполняться только в том случае, если команда перед архивацией завершится без ошибок (код возврата 0).</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="496"/>
        <source>Pre-backup command to run BEFORE backups</source>
        <translation>Команда, выполняемая ПЕРЕД архивацией</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="506"/>
        <source>Post-backup command to run AFTER backups</source>
        <translation>Команда, выполняемая ПОСЛЕ архивации</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="519"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Available env variables: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Доступные переменные окружения: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="20"/>
        <source>Source Folders and Files to Back Up:</source>
        <translation>Исходные папки и файлы для архивации:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="94"/>
        <source>Add Folder</source>
        <translation>Добавить папку</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="108"/>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="164"/>
        <source>Exclude If Present (exclude folders with these files):</source>
        <translation>Исключить при наличии (пропуск папок с этими файлами):</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="135"/>
        <source>Diff</source>
        <translation>Сравнить</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="183"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To mount archives, first install &amp;quot;FUSE for macOS&amp;quot; from &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;here&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Для монтирования архивов установите &amp;quot;FUSE для macOS&amp;quot; &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;отсюда&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="208"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pruning removes older archives. You can choose the number of hourly, daily, etc. archives to preserve. Usually you will keep more newer and fewer old archives. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Очистка удаляет старые архивы. Можно выбрать число хранимых архивов за день, неделю и т.д. Обычно сохраняются самые последние и несколько старых архивов. &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;Узнать больше&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="64"/>
        <source>Vorta Version:</source>
        <translation>Версия Vorta:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Report&lt;/span&gt;&lt;/a&gt; a Bug |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Сообщить&lt;/span&gt;&lt;/a&gt; об ошибке |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="91"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Log&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Журнал&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="127"/>
        <source>Borg Version:</source>
        <translation>Версия Borg:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="134"/>
        <source>1.1.8</source>
        <translation>1.1.8</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="141"/>
        <source>/usr/bin/borg</source>
        <translation>/usr/bin/borg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="96"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remote or local backup repository. For simple and secure backup hosting, try &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Удалённый или локальный репозиторий. Для простой и безопасной архивации попробуйте использовать хостинг &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="288"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Compression used for new data. Can be changed and doesn&apos;t affect deduplication. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Метод сжатия данных. Не влияет на дедупликацию. Узнать &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;больше&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="154"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Exclude Patterns (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Шаблоны исключения (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;узнать больше&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="180"/>
        <source>E.g. **/.cache</source>
        <translation>Напр. **/.cache</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="193"/>
        <source>E.g. .nobackup</source>
        <translation>Напр. .nobackup</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="146"/>
        <source>Copy repo URL to clipboard</source>
        <translation>Скопировать адрес в буфер обмена</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="364"/>
        <source>Don&apos;t run backup over metered networks</source>
        <translation>Не архивировать через платное соединение</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="101"/>
        <source>Add File(s)</source>
        <translation>Добавить файл(ы)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="115"/>
        <source>One folder or file per line</source>
        <translation>Одна папка или файл на строку</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="118"/>
        <source>Paste Folders/Files</source>
        <translation>Вставить папки/файлы</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="434"/>
        <source>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</source>
        <translation>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="69"/>
        <source>Path</source>
        <translation>Путь</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="74"/>
        <source>Type</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="84"/>
        <source>File Count</source>
        <translation>Количество файлов</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="125"/>
        <source>Recalculate sizes</source>
        <translation>Пересчитать размеры</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="102"/>
        <source>Selected Archive</source>
        <translation>Выбранный архив</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="542"/>
        <source>Add these arguments when creating a backup. See &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;the documentation&lt;/span&gt;&lt;/a&gt; for more information.</source>
        <translation>Аргументы, добавляемые при запуске архивации. Смотрите &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;документацию&lt;/span&gt;&lt;/a&gt; для дополнительной информации.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="558"/>
        <source>Arguments to add. E.g. --dry-run</source>
        <translation>Добавляемые аргументы, например --dry-run</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="198"/>
        <source>-</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="252"/>
        <source>Run missed backups right after startup or wakeup</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImportWindow</name>
    <message>
        <location filename="../../views/import_window.py" line="25"/>
        <source>Import Profile</source>
        <translation>Импортировать профиль</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="33"/>
        <source>The passphrase has been loaded from the export file</source>
        <translation>Пароль был загружен из файла экспорта</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="40"/>
        <source>The passphrase has been loaded from your keyring</source>
        <translation>Пароль был загружен из вашей связки ключей</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="50"/>
        <source>A profile with the name {} does not exist. Nothing to overwrite.</source>
        <translation>Профиль с именем {} не существует. Перезаписывать нечего.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="61"/>
        <source>Error while importing</source>
        <translation>Ошибка при импорте</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="77"/>
        <source>Schema upgrade failure, file a bug report with the link in the Misc tab with the following error: 
 {0} 
 {1}</source>
        <translation>Сбой обновления схемы. Отправьте сообщение об ошибке по ссылке на вкладке Разное со следующим текстом ошибки: 
 {0} 
 {1}</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="80"/>
        <source>Newer profile_export export files cannot be used on older versions.</source>
        <translation>Новые файлы экспорта profile_export не могут быть использованы в более старых версиях.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="82"/>
        <source>Cannot read profile_export export file due to permission error.</source>
        <translation>Невозможно прочитать файл экспорта profile_export из-за ошибки прав доступа.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="84"/>
        <source>Profile export file not found.</source>
        <translation>Не найден файл экспорта профиля.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../views/main_window.py" line="255"/>
        <source>Task cancelled</source>
        <translation>Задача отменена</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="51"/>
        <source>Current Profile:</source>
        <translation>Текущий профиль:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="84"/>
        <source>Rename Profile</source>
        <translation>Переименовать профиль</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="107"/>
        <source>Delete Profile</source>
        <translation>Удалить профиль</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="148"/>
        <source>Repository</source>
        <translation>Репозиторий</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="153"/>
        <source>Sources</source>
        <translation>Источники</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="158"/>
        <source>Schedule</source>
        <translation>Расписание</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="163"/>
        <source>Archives</source>
        <translation>Архивы</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="168"/>
        <source>Misc</source>
        <translation>Разное</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="190"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="36"/>
        <source>Start Backup</source>
        <translation>Начать архивацию</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="239"/>
        <source>Latest</source>
        <translation>Последний</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="244"/>
        <source>Reset App</source>
        <translation>Сбросить приложение</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="68"/>
        <source>Add Profile</source>
        <translation>Добавить профиль</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="163"/>
        <source>Are you sure you want to delete profile &apos;{}&apos;?</source>
        <translation>Вы действительно хотите удалить профиль &apos;{}&apos;?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="164"/>
        <source>Confirm deletion</source>
        <translation>Подтверждение удаления</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="272"/>
        <source>Should Vorta continue to run in the background?</source>
        <translation>Следует ли Vorta продолжить работать в фоне?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="277"/>
        <source>Quit</source>
        <translation>Выйти</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="278"/>
        <source>Don&apos;t show this again</source>
        <translation>Не показывать снова</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="83"/>
        <source>Import from file...</source>
        <translation>Импорт из файла...</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="174"/>
        <source>Can&apos;t delete the last profile.</source>
        <translation>Невозможно удалить последний профиль.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="202"/>
        <source>Profile import successful!</source>
        <translation>Профиль успешно импортирован!</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="202"/>
        <source>Profile {} imported.</source>
        <translation>Профиль {} импортирован.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>Load profile</source>
        <translation>Импорт профиля</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>JSON (*.json);;All files (*)</source>
        <translation>JSON (*.json);;Все файлы (*)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="97"/>
        <source>Export Profile</source>
        <translation>Экспортировать профиль</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="220"/>
        <source>Failed to import profile</source>
        <translation>Ошибка импорта профиля</translation>
    </message>
</context>
<context>
    <name>RepoTab</name>
    <message>
        <location filename="../../views/repo_tab.py" line="26"/>
        <source>+ Initialize New Repository</source>
        <translation>+ Создать новый репозиторий</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="27"/>
        <source>+ Add Existing Repository</source>
        <translation>+ Добавить существующий репозиторий</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="48"/>
        <source>No Compression</source>
        <translation>Без сжатия</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="111"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Автоматически выбирать ключ SSH (по умолчанию)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="112"/>
        <source>Create New Key</source>
        <translation>Создать новый ключ</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="149"/>
        <source>Public Key Copied to Clipboard</source>
        <translation>Открый ключ скопирован в буфер обмена</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="150"/>
        <source>The selected public SSH key was copied to the clipboard. Use it to set up remote repo permissions.</source>
        <translation>Выбранный ключ SSH был скопирован в буфер обмена. Используйте его при настройке удаленного репозитория.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="155"/>
        <source>Couldn&apos;t find public key.</source>
        <translation>Не удалось найти открытый ключ.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="157"/>
        <source>Select a public key from the dropdown first.</source>
        <translation>Сначала выберите открытый ключ из списка.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="213"/>
        <source>Repository was Unlinked</source>
        <translation>Репозиторий был отвязан</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="214"/>
        <source>You can always connect it again later.</source>
        <translation>Вы всегда можете переподключиться к нему позднее.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="38"/>
        <source>LZ4 (modern, default)</source>
        <translation>LZ4 (современное, по умолчанию)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="39"/>
        <source>Zstandard Level 3 (modern)</source>
        <translation>Zstandard уровня 3 (современное)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="40"/>
        <source>Zstandard Level 8 (modern)</source>
        <translation>Zstandard уровня 8 (современное)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="46"/>
        <source>ZLIB Level 6 (auto, legacy)</source>
        <translation>ZLIB уровня 6 (авто, устарело)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="47"/>
        <source>LZMA Level 6 (auto, legacy)</source>
        <translation>LZMA уровня 6 (авто, устарело)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="228"/>
        <source>Select a repository from the dropdown first.</source>
        <translation>Сначала выберите репозиторий из списка.</translation>
    </message>
</context>
<context>
    <name>SSHAddWindow</name>
    <message>
        <location filename="../../views/ssh_dialog.py" line="35"/>
        <source>ED25519 (Recommended)</source>
        <translation>ED25519 (рекомендуется)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="36"/>
        <source>RSA (Legacy)</source>
        <translation>RSA (устарело)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="37"/>
        <source>ECDSA</source>
        <translation>ECDSA</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="46"/>
        <source>High (Recommended)</source>
        <translation>Высокая (рекомендуется)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="47"/>
        <source>Medium</source>
        <translation>Средняя</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="60"/>
        <source>Key file already exists. Not overwriting.</source>
        <translation>Файл ключа уже существует и не будет перезаписан.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="72"/>
        <source>New key was copied to clipboard and written to %s.</source>
        <translation>Новый ключ был скопирован в буфер обмена и записан в %s.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="74"/>
        <source>Error during key generation.</source>
        <translation>Ошибка при создании ключа.</translation>
    </message>
</context>
<context>
    <name>ScheduleTab</name>
    <message>
        <location filename="../../views/schedule_tab.py" line="43"/>
        <source>Minutes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="44"/>
        <source>Hours</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="45"/>
        <source>Days</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="46"/>
        <source>Weeks</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SourceTab</name>
    <message>
        <location filename="../../views/source_tab.py" line="173"/>
        <source>Choose directory to back up</source>
        <translation>Выберите папку для архивации</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="173"/>
        <source>Choose file(s) to back up</source>
        <translation>Выберите файл(ы) для архивации</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="130"/>
        <source>Folder</source>
        <translation>Папка</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="134"/>
        <source>File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="102"/>
        <source>Calculating...</source>
        <translation>Вычисление...</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="164"/>
        <source>You don&apos;t have read access to {dir}.</source>
        <translation>У вас нет прав на чтение {dir}.</translation>
    </message>
</context>
<context>
    <name>TrayMenu</name>
    <message>
        <location filename="../../tray_menu.py" line="42"/>
        <source>Vorta for Borg Backup</source>
        <translation>Архиватор Vorta для Borg</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="53"/>
        <source>Cancel Backup</source>
        <translation>Отмена архивации</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="56"/>
        <source>Next Task: %s</source>
        <translation>Следующая задача: %s</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="65"/>
        <source>Backup Now</source>
        <translation>Запустить архивацию</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="70"/>
        <source>Quit</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="52"/>
        <source>Task in progress</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VortaApp</name>
    <message>
        <location filename="../../application.py" line="129"/>
        <source>Vorta Backup</source>
        <translation>Архиватор Vorta</translation>
    </message>
    <message>
        <location filename="../../application.py" line="191"/>
        <source>No Borg Binary Found</source>
        <translation>Исполняемый файл Borg не найден</translation>
    </message>
    <message>
        <location filename="../../application.py" line="192"/>
        <source>Vorta was unable to locate a usable Borg Backup binary.</source>
        <translation>Не удалось найти подходящий исполняемый файл Borg Backup.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="229"/>
        <source>Repository In Use</source>
        <translation>Используемый репозиторий</translation>
    </message>
    <message>
        <location filename="../../application.py" line="231"/>
        <source>Abort</source>
        <translation>Прервать</translation>
    </message>
    <message>
        <location filename="../../application.py" line="232"/>
        <source>Continue</source>
        <translation>Продолжить</translation>
    </message>
    <message>
        <location filename="../../application.py" line="234"/>
        <source>The repository at {repo_url} might be in use elsewhere.</source>
        <translation>Репозиторий {repo_url} может использоваться в другом месте.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="235"/>
        <source>Only break the lock if you are certain no other Borg process on any machine is accessing the repository. Abort or break the lock?</source>
        <translation>Снимайте блокировку, только если вы уверены, что никакой другой процесс Borg на любой машине не имеет доступа к репозиторию. Прервать операцию или снять блокировку?</translation>
    </message>
    <message>
        <location filename="../../application.py" line="243"/>
        <source>You do not have permission to access the repository at {repo_url}. Gain access and try again.</source>
        <translation>У вас нет прав на доступ к репозиторию {repo_url}. Получите недостающие права и попробуйте ещё раз.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="246"/>
        <source>No Repository Permissions</source>
        <translation>Недостаточно прав</translation>
    </message>
    <message>
        <location filename="../../application.py" line="210"/>
        <source>Vorta needs Full Disk Access for complete Backups</source>
        <translation>Vorta требуются Full Disk Access права для завершения архивирования</translation>
    </message>
    <message>
        <location filename="../../application.py" line="211"/>
        <source>Without this, some files won&apos;t be accessible and you may end up with an incomplete backup. Please set &lt;b&gt;Full Disk Access&lt;/b&gt; permission for Vorta in &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;System Preferences &gt; Security &amp; Privacy&lt;/a&gt;.</source>
        <translation>Без этого некоторые файлы будут недоступны, и архивирование может быть завершено не полностью. Пожалуйста, выдайте&lt;b&gt;Full Disk Access&lt;/b&gt; права для Vorta в &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;System Preferences &gt; Security &amp; Privacy&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="283"/>
        <source>Profile import successful!</source>
        <translation>Профиль успешно импортирован!</translation>
    </message>
    <message>
        <location filename="../../application.py" line="283"/>
        <source>Profile {} imported.</source>
        <translation>Профиль {} импортирован.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Failed to import profile</source>
        <translation>Ошибка импорта профиля</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Failed to import a profile from {}:</source>
        <translation>Ошибка импорта профиля из {}:</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Consider removing or repairing this file to get rid of this message.</source>
        <translation>Рассмотрите возможность удаления или восстановления данного файла для того, чтобы избежать этого сообщения.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="295"/>
        <source>Repo Check Failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="296"/>
        <source>Repository data check for repo %s failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../../application.py" line="297"/>
        <source>Repair or recreate the repository soon to avoid missing data.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VortaScheduler</name>
    <message>
        <location filename="../../scheduler.py" line="143"/>
        <source>None scheduled</source>
        <translation>Не запланировано</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="190"/>
        <source>Vorta Backup</source>
        <translation>Архиватор Vorta</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="162"/>
        <source>Starting background backup for %s.</source>
        <translation>Запуск фоновой архивации для %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="184"/>
        <source>Backup successful for %s.</source>
        <translation>Успешная архивация для %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="190"/>
        <source>Error during backup creation.</source>
        <translation>Ошибка при создании архива.</translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="../../__main__.py" line="22"/>
        <source>Fatal Error</source>
        <translation>Критическая ошибка</translation>
    </message>
    <message>
        <location filename="../../__main__.py" line="23"/>
        <source>Uncaught exception, please file a report with this text at
https://github.com/borgbase/vorta/issues/new
</source>
        <translation>Неожиданная ошибка. Пожалуйста, отправьте отчет с этим текстом по адресу
https://github.com/borgbase/vorta/issues/new
</translation>
    </message>
</context>
<context>
    <name>messages</name>
    <message>
        <location filename="../../borg/version.py" line="20"/>
        <source>Borg binary was not found.</source>
        <translation>Исполняемый файл Borg не найден.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="140"/>
        <source>Add a backup repository first.</source>
        <translation>Сначала добавьте репозиторий.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="82"/>
        <source>Add some folders to back up first.</source>
        <translation>Сначала добавьте папки для резервирования.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="98"/>
        <source>Current Wifi is not allowed.</source>
        <translation>Текущее Wifi-подключение не разрешено.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="115"/>
        <source>Repo folder not mounted or moved.</source>
        <translation>Папка репозитория не смонтирована или перемещена.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="111"/>
        <source>Pre-backup command returned non-zero exit code.</source>
        <translation>Команда перед архивацией вернула ненулевой код ошибки.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="165"/>
        <source>Starting backup...</source>
        <translation>Начало архивации...</translation>
    </message>
    <message>
        <location filename="../../borg/umount.py" line="27"/>
        <source>No active Borg mounts found.</source>
        <translation>Нет активных точек монтирования Borg.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="144"/>
        <source>Your Borg version is too old. &gt;=1.1.0 is required.</source>
        <translation>Ваша версия Borg устарела. Требуется &gt;=1.1.0.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="119"/>
        <source>Your current Borg version does not support ZStd compression.</source>
        <translation>Ваша текущая версия Borg не поддерживает сжатие ZStd.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="103"/>
        <source>Not running backup over metered connection.</source>
        <translation>Архивация не выполняется из-за платного соединения.</translation>
    </message>
    <message>
        <location filename="../../borg/info_repo.py" line="43"/>
        <source>Please unlock your password manager.</source>
        <translation>Пожалуйста, разблокируйте свой менеджер паролей.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="171"/>
        <source>Your repo passphrase was stored in a password manager which is no longer available.
Try unlinking and re-adding your repo.</source>
        <translation>Пароль вашего репозитория был сохранён в менеджере паролей, который больше не доступен. Попробуйте отвязать и переподключить ваш репозиторий.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="155"/>
        <source>Please unlock your system password manager or disable it under Misc</source>
        <translation>Пожалуйста, разблокируйте системный менеджер паролей или отключите его использование на вкладке Разное</translation>
    </message>
</context>
<context>
    <name>utils</name>
    <message>
        <location filename="../../utils.py" line="412"/>
        <source>Passwords must be identical and greater than 8 characters long.</source>
        <translation>Пароли должны совпадать и быть длиннее 8 символов.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="414"/>
        <source>Passwords must be identical.</source>
        <translation>Пароли должны совпадать.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="416"/>
        <source>Passwords must be greater than 8 characters long.</source>
        <translation>Пароль должен быть длиннее 8 символов.</translation>
    </message>
</context>
</TS>